summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xlib/make/configure8
-rw-r--r--lib/make/configure.in2
-rw-r--r--lib/sbin/CreateParameterBindings.pl4
-rw-r--r--lib/sbin/create_c_stuff.pl2
-rw-r--r--src/main/ActiveThorns.c2
-rw-r--r--src/main/Banner.c2
-rw-r--r--src/main/DefaultTimers.c2
-rw-r--r--src/main/Parameters.c2
-rw-r--r--src/main/WarnLevel.c2
-rw-r--r--src/util/Misc.c2
-rw-r--r--src/util/getopt.c10
-rw-r--r--src/util/getopt1.c9
-rw-r--r--src/util/gnu_regex.c2
13 files changed, 26 insertions, 23 deletions
diff --git a/lib/make/configure b/lib/make/configure
index 78080a7e..359d8a74 100755
--- a/lib/make/configure
+++ b/lib/make/configure
@@ -2828,11 +2828,11 @@ LDFLAGS="$KNOWN_LDFLAGS $LDFLAGS"
: ${L2_CACHE_SIZE="0"}
cat >> confdefs.h <<EOF
-#define CCTK_CACHELINE_BYTES $L2_CACHELINE_BYTES
+#define CCTK_L2_CACHELINE_BYTES $L2_CACHELINE_BYTES
EOF
cat >> confdefs.h <<EOF
-#define CCTK_CACHE_SIZE $L2_CACHE_SIZE
+#define CCTK_L2_CACHE_SIZE $L2_CACHE_SIZE
EOF
@@ -2940,7 +2940,7 @@ done
ac_given_srcdir=$srcdir
-trap 'rm -fr `echo "make.config.defn make.config.deps make.config.rules config.h" | sed "s/:[^ ]*//g"` conftest*; exit 1' 1 2 15
+trap 'rm -fr `echo "make.config.defn make.config.deps make.config.rules cctk_config.h" | sed "s/:[^ ]*//g"` conftest*; exit 1' 1 2 15
EOF
cat >> $CONFIG_STATUS <<EOF
@@ -3147,7 +3147,7 @@ ac_eD='%g'
if test "${CONFIG_HEADERS+set}" != set; then
EOF
cat >> $CONFIG_STATUS <<EOF
- CONFIG_HEADERS="config.h"
+ CONFIG_HEADERS="cctk_config.h"
EOF
cat >> $CONFIG_STATUS <<\EOF
fi
diff --git a/lib/make/configure.in b/lib/make/configure.in
index ab23f0cf..5b1f183b 100644
--- a/lib/make/configure.in
+++ b/lib/make/configure.in
@@ -17,7 +17,7 @@ AC_PREREQ(2.13)
dnl Starts here
AC_INIT()
-AC_CONFIG_HEADER(config.h)
+AC_CONFIG_HEADER(cctk_config.h)
dnl Check the system type
AC_CANONICAL_SYSTEM
diff --git a/lib/sbin/CreateParameterBindings.pl b/lib/sbin/CreateParameterBindings.pl
index 0cd5a146..b62261c4 100644
--- a/lib/sbin/CreateParameterBindings.pl
+++ b/lib/sbin/CreateParameterBindings.pl
@@ -196,7 +196,7 @@ sub CreateParameterBindings
$dataout .= "\#include <stdio.h>\n";
$dataout .= "\#include <stdlib.h>\n";
$dataout .= "\#include <string.h>\n";
- $dataout .= "\#include \"config.h\"\n";
+ $dataout .= "\#include \"cctk_config.h\"\n";
$dataout .= "\#include \"cctk_Misc.h\"\n";
$dataout .= "\#include \"cctk_WarnLevel.h\"\n";
@@ -478,7 +478,7 @@ sub NewParamStuff
push(@data, "#include <stdarg.h>");
push(@data, "");
- push(@data, "#include \"config.h\"");
+ push(@data, "#include \"cctk_config.h\"");
push(@data, "#include \"ParameterBindings.h\"");
push(@data, "#include \"CParameterStructNames.h\"");
diff --git a/lib/sbin/create_c_stuff.pl b/lib/sbin/create_c_stuff.pl
index fa6ba966..c2414ec6 100644
--- a/lib/sbin/create_c_stuff.pl
+++ b/lib/sbin/create_c_stuff.pl
@@ -41,7 +41,7 @@ sub CreateParameterBindingFile
push(@data, $line);
$line = "\#include <stdarg.h>";
push(@data, $line);
- $line = "\#include \"config.h\"";
+ $line = "\#include \"cctk_config.h\"";
push(@data, $line);
$line = "\#include \"CParameterStructNames.h\"";
push(@data, $line);
diff --git a/src/main/ActiveThorns.c b/src/main/ActiveThorns.c
index 8ade276c..2a76a5f0 100644
--- a/src/main/ActiveThorns.c
+++ b/src/main/ActiveThorns.c
@@ -13,7 +13,7 @@
#include "SKBinTree.h"
-#include "config.h"
+#include "cctk_config.h"
#include "cctk_ActiveThorns.h"
#include "cctk_FortranString.h"
diff --git a/src/main/Banner.c b/src/main/Banner.c
index 27e01af5..dc90bc26 100644
--- a/src/main/Banner.c
+++ b/src/main/Banner.c
@@ -12,7 +12,7 @@
#include <stdio.h>
#include <stdlib.h>
-#include "config.h"
+#include "cctk_config.h"
#include "cctk_parameters.h"
#include "cctk_Banner.h"
#include "cctk_FortranString.h"
diff --git a/src/main/DefaultTimers.c b/src/main/DefaultTimers.c
index 523ccd3b..63f679d9 100644
--- a/src/main/DefaultTimers.c
+++ b/src/main/DefaultTimers.c
@@ -12,7 +12,7 @@ static char *rcsid = "$Header$";
#include <stdio.h>
#include <stdlib.h>
-#include "config.h"
+#include "cctk_config.h"
#if TIME_WITH_SYS_TIME
# include <sys/time.h>
diff --git a/src/main/Parameters.c b/src/main/Parameters.c
index 14e04a22..43f3f10b 100644
--- a/src/main/Parameters.c
+++ b/src/main/Parameters.c
@@ -9,7 +9,7 @@
const char *rcsid="$Header$";
-#include "config.h"
+#include "cctk_config.h"
#include <stdio.h>
#include <stdlib.h>
diff --git a/src/main/WarnLevel.c b/src/main/WarnLevel.c
index f1158104..3f45bc49 100644
--- a/src/main/WarnLevel.c
+++ b/src/main/WarnLevel.c
@@ -8,7 +8,7 @@
@@*/
-#include "config.h"
+#include "cctk_config.h"
#include <stdio.h>
#include <stdlib.h>
diff --git a/src/util/Misc.c b/src/util/Misc.c
index 43ef71d7..d3c7fbd9 100644
--- a/src/util/Misc.c
+++ b/src/util/Misc.c
@@ -23,7 +23,7 @@
#include "gnu_regex.h"
-#include "config.h"
+#include "cctk_config.h"
#include "cctk_Misc.h"
#include "cctk_FortranString.h"
#include "cctk_WarnLevel.h"
diff --git a/src/util/gnu_regex.c b/src/util/gnu_regex.c
index 529cc4d1..a2b3d149 100644
--- a/src/util/gnu_regex.c
+++ b/src/util/gnu_regex.c
@@ -44,7 +44,7 @@ static char *rcsid = "$Id$";
#include <sys/types.h>
#ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "cctk_config.h"
#endif
/* The `emacs' switch turns on certain matching commands
diff --git a/src/util/getopt.c b/src/util/getopt.c
index bc5b54f1..e12478c8 100644
--- a/src/util/getopt.c
+++ b/src/util/getopt.c
@@ -31,12 +31,14 @@ char * getenv(const char *);
#ifdef HAVE_CONFIG_H
#if defined (emacs) || defined (CONFIG_BROKETS)
-/* We use <config.h> instead of "config.h" so that a compilation
- using -I. -I$srcdir will use ./config.h rather than $srcdir/config.h
+/* We use <cctk_config.h> instead of "cctk_config.h" so that a compilation
+ using -I. -I$srcdir will use ./cctk_config.h rather than
+ $srcdir/cctk_config.h
(which it would do because it found this file in $srcdir). */
-#include <config.h>
+#include <cctk_config.h>
#else
-#include "config.h"
+/*Gab */
+#include "cctk_config.h"
#endif
#endif
diff --git a/src/util/getopt1.c b/src/util/getopt1.c
index 505ae73e..05cf0c7c 100644
--- a/src/util/getopt1.c
+++ b/src/util/getopt1.c
@@ -14,12 +14,13 @@
#ifdef HAVE_CONFIG_H
#if defined (emacs) || defined (CONFIG_BROKETS)
-/* We use <config.h> instead of "config.h" so that a compilation
- using -I. -I$srcdir will use ./config.h rather than $srcdir/config.h
+/* We use <cctk_config.h> instead of "cctk_config.h" so that a compilation
+ using -I. -I$srcdir will use ./cctk_config.h rather than
+ $srcdir/cctk_config.h
(which it would do because it found this file in $srcdir). */
-#include <config.h>
+#include <cctk_config.h>
#else
-#include "config.h"
+#include "cctk_config.h"
#endif
#endif